## Language
[简体中文](https://github.com/kszitt/next-oss/blob/master/README.md)

## Description
Upload the files generated by webpack to the cloud to improve the loading speed  
Currently, only `aliyun` is supported. Based on `ali-oss` module  

## Install
```bash
npm install next-oss --save-dev
```

## Compatibility
### Node
Node.js >= 10.10.0 required

## Non `next` framework
#### Add command
```jsx
// package.json
{
  "folder": "<Cloud folder>",
  "OSSDomainName": "<Cloud domain name>",
}
```
#### Webpack profile
```jsx
// webpack.config.js
const NextOss = require('next-oss');
const {folder, OSSDomainName} = require('./package.json');

...
output: {
  ...
  publicPath: process.env.NODE_ENV === "production" ? `${OSSDomainName}/${folder}/` : "/"
}
...
plugins: [
  ...
  new NextOss({
    folder,
    disable: process.env.NODE_ENV !== "production",
    aliyun: {
      region: "<OSS region>",
      accessKeyId: "<Your accessKeyId>",
      accessKeySecret: "<Your accessKeySecret>",
      bucket: "<Your bucket name>"
    }
  })
]
```
## `next` framework
#### Add command
```jsx
// package.json
{
  "folder": "<Cloud folder>",
  "OSSDomainName": "<Cloud domain name>",
  "scripts": {
    "build": "cross-env NODE_ENV=production next build",  // build command
    "start": "cross-env NODE_ENV=production node server.js"   // start service (You cannot use `next start` here. You need to customize the server)
  }
}
```
#### Custom server
```jsx
// server.js
const express = require('express');
const next = require('next');
const {folder, OSSDomainName} = require('./package.json');
const { NODE_ENV, PORT=3000 } = process.env;
const dev = NODE_ENV !== 'production';
const app = next({dir: '.', dev});


app.prepare().then(() => {
    const server = express();

    // Dynamic prefix
    if(NODE_ENV === "production") app.setAssetPrefix(`${OSSDomainName}/${folder}`);

    server.listen(PORT, (err) => {
      if (err) {
        throw err
      }
      console.log(`> Ready on port ${PORT} [${NODE_ENV}]`);
    })
  }).catch((ex) => {
    console.log('An error occurred, unable to start the server')
    console.log(ex)
  });
```
#### Webpack profile
```jsx
// next.config.js
const NextOss = require('next-oss');
const {folder} = require('./package.json');
const withPlugins = require ("next-compose-plugins");

...
const nextConfig = {
  webpack: (config, options) => {
    ...
    if(!options.isServer){
      config.plugins.push(
        new NextOss({
         folder,
         disable: NODE_ENV !== "production",
         aliyun: {
           region: "<OSS region>",
           accessKeyId: "<Your accessKeyId>",
           accessKeySecret: "<Your accessKeySecret>",
           bucket: "<Your bucket name>"
         }
        })
      );
    }

    return config;
  }
};

module.exports = withPlugins([...], nextConfig);
```

## NextOSS(options):
- `Folder` - Folder to save to cloud
- `aliyun` - Initialize aliyun information
- `disable` - Is it disable? default`false`
- `deletePrevBuildFile` - Delete previous versions of cloud, default`false`
- `log` - Show log or not, default`false`
